/**
 * Implementation of the `akismet.Blog` class.
 * @module core.blog
 */
part of akismet.core;

/**
 * Represents the front page or home URL transmitted when making requests.
 * @class akismet.Blog
 * @constructor
 * @param {Uri} url The blog or site URL.
 */
class Blog {

  Blog(this.url);

  /**
   * Creates a new instance from the specified map in JSON format.
   * @method fromJson
   * @param {Map&lt;String, String&gt;} map A map in JSON format specifying the object properties.
   * @return {akismet.Blog} The author corresponding to the specified map.
   * @static
   */
  Blog.fromJson(Map<String, String> map) {
    assert(map!=null);

    if(map['blog']!=null) url=Uri.parse(map['blog']);
    if(map['blog_charset']!=null) charset=map['blog_charset'];
    if(map['blog_lang']!=null) language=map['blog_lang'];
  }

  /**
   * The character encoding for the values included in comments.
   * @property charset
   * @type String
   */
  String charset;

  /**
   * The language(s) in use on the blog or site.
   * @property language
   * @type String
   */
  String language;

  /**
   * The blog or site URL.
   * @property url
   * @type String
   */
  Uri url;

  /**
   * Converts this object to a map in JSON format.
   * @method toJson
   * @return {Map&lt;String, String&gt;} The map in JSON format corresponding to this object.
   */
  Map<String, String> toJson() {
    var map={};

    if(url!=null) map['blog']=url.toString();
    if(charset!=null) map['blog_charset']=charset;
    if(language!=null) map['blog_lang']=language;

    return map;
  }

  /**
   * Returns a string representation of this object.
   * @method toString
   * @return {String} A string that represents the current object.
   */
  @override
  String toString() => 'Blog ${toJson()}';
}