/**
 * Implementation of the `akismet.html.Client` class.
 * @module html.client
 */
part of akismet.html;

/**
 * A `dart:html` client that submit comments to [Akismet](https://akismet.com) service.
 * @class akismet.html.Client
 * @extends akismet.Client
 * @constructor
 * @param {String} apiKey The Akismet API key.
 * @param {Uri|akismet.Blog} blog The front page or home URL.
 */
class Client extends core.Client {

  Client(String apiKey, blog): super(apiKey, blog) {
    userAgent='Dart/0.0.0 | Akismet/${core.VERSION}';
  }

  /**
   * Queries the remote service by posting the specified fields to a given end point.
   * @method queryService
   * @return {Future&lt;String&gt;} The response as a string.
   * @async
   */
  Future<String> queryService(Uri endPoint, Map<String, String> fields) {
    assert(endPoint!=null);
    assert(fields!=null);

    fields['key']=apiKey;
    fields.addAll(blog.toJson());

    var headers={
      core.HttpHeaders.X_REQUESTED_WITH: 'XMLHttpRequest',
      core.HttpHeaders.X_USER_AGENT: userAgent
    };

    return HttpRequest.postFormData(endPoint.toString(), fields, requestHeaders: headers, responseType: 'text').then((request) {
      if(request.responseHeaders.containsKey(core.HttpHeaders.X_AKISMET_DEBUG_HELP))
        throw new HttpException(request.responseHeaders[core.HttpHeaders.X_AKISMET_DEBUG_HELP], uri: endPoint);

      return request.responseText;
    });
  }
}

/**
 * Describes an exception that occurred during the processing of HTTP requests.
 * @class akismet.html.HttpException
 * @uses Exception
 * @constructor
 * @param {String} message A message that describes the current exception.
 * @param {Uri} [uri] The requested URI that caused the exception.
 */
class HttpException implements Exception {

  const HttpException(this.message, { this.uri });

  /**
   * A message that describes the current exception.
   * @property message
   * @type String
   * @final
   */
  final String message;

  /**
   * The requested `Uri` that caused the exception.
   * @property uri
   * @type Uri
   * @final
   */
  final Uri uri;

  /**
   * Returns a string representation of this object.
   * @method toString
   * @return {String} A string that represents the current object.
   */
  @override
  String toString() => 'HttpException { message: "$message", uri: "$uri" }';
}
