/**
 * Implementation of the `akismet.io.Client` class.
 * @module io.client
 */
part of akismet.io;

/**
 * A `dart:io` client that submit comments to [Akismet](https://akismet.com) service.
 * @class akismet.io.Client
 * @extends akismet.Client
 * @constructor
 * @param {String} apiKey The Akismet API key.
 * @param {Uri|akismet.Blog} blog The front page or home URL.
 */
class Client extends core.Client {

  Client(String apiKey, blog): super(apiKey, blog) {
    var dartVersion=Platform.version.split('.').take(3).join('.');
    userAgent='Dart/$dartVersion | Akismet/${core.VERSION}';
  }

  /**
   * Queries the remote service by posting the specified fields to a given end point.
   * @method queryService
   * @return {Future&lt;String&gt;} The response as a string.
   * @async
   */
  Future<String> queryService(Uri endPoint, Map<String, String> fields) {
    assert(endPoint!=null);
    assert(fields!=null);

    fields.addAll(blog.toJson());

    return http.post(endPoint, body: fields, headers: { HttpHeaders.USER_AGENT: userAgent }).then((response) {
      if(response.headers.containsKey(core.HttpHeaders.X_AKISMET_DEBUG_HELP))
        throw new HttpException(response.headers[core.HttpHeaders.X_AKISMET_DEBUG_HELP], uri: endPoint);

      return response.body;
    });
  }
}
