/**
 * Implementation of the `tests.core.BlogTest` class.
 * @module test.blog_test
 */
part of akismet.tests.core;

/**
 * Tests the features of `core.Blog` class.
 * @class akismet.tests.BlogTest
 * @constructor
 */
class BlogTest {

  /**
   * Runs the unit tests.
   * @method run
   */
  void run() {
    group('Blog', () {
      test('fromJson()', testFromJson);
      test('toJson()', testToJson);
    });
  }

  /**
   * Tests the `fromJson` constructor.
   * @method testFromJson
   */
  void testFromJson() {
    var blog=new Blog.fromJson(JSON.decode('{}'));
    expect(blog.charset, isNull);
    expect(blog.language, isNull);
    expect(blog.url, isNull);

    blog=new Blog.fromJson(JSON.decode('{ "blog": "http://dev.belin.io/akismet.dart", "blog_charset": "UTF-8", "blog_lang": "en" }'));
    expect(blog.charset, equals('UTF-8'));
    expect(blog.language, equals('en'));
    expect(blog.url, equals(Uri.parse('http://dev.belin.io/akismet.dart')));
  }

  /**
   * Tests the `toJson` method.
   * @method testToJson
   */
  void testToJson() {
    var blog=new Blog();
    expect(JSON.encode(blog), equals('{}'));

    blog=new Blog(Uri.parse('http://dev.belin.io/akismet.dart'))
      ..charset='UTF-8'
      ..language='en';

    expect(JSON.encode(blog), equals('{"blog":"http://dev.belin.io/akismet.js","blog_charset":"UTF-8","blog_lang":"en"}'));
  }
}
